%global with_check 0
%global import_path github.com/containers/podman

%global container_base_path github.com/containers
%global container_base_url https://%{container_base_path}

# For LDFLAGS
%global ld_project %{container_base_path}/%{name}/v4
%global ld_libpod %{ld_project}/libpod

# dnsname
%global repo_plugins dnsname
%global git_plugins %{container_base_url}/%{repo_plugins}
%global commit_plugins 18822f9a4fb35d1349eb256f4cd2bfd372474d84
%global import_path_plugins %{container_base_path}/%{repo_plugins}

Summary:       Manage Pods, Containers and Container Images
Name:          podman
Version:       4.9.5
Release:       4%{?dist}
License:       Apache-2.0 AND BSD-2-Clause AND BSD-3-Clause AND ISC AND MIT AND MPL-2.0
URL:           https://%{name}.io/
Source0:       https://%{import_path}/archive/refs/tags/v%{version}.tar.gz #/%{name}-%{version}.tar.gz
Source1:       %{git_plugins}/archive/%{commit_plugins}/%{repo_plugins}-%{commit_plugins}.tar.gz
Patch0:        0001-podman-4.9.3-add-support-for-loongarch64.patch

BuildRequires: gcc make autoconf automake pkgconfig libtool
BuildRequires: glib2-devel glibc-devel glibc-static git-core
BuildRequires: gpgme-devel libassuan-devel libgpg-error-devel
BuildRequires: libseccomp-devel libselinux-devel ostree-devel
BuildRequires: systemd systemd-devel shadow-utils-subid-devel
BuildRequires: golang go-md2man file gettext go-rpm-macros
Requires:      containers-common containers-common-extra fuse-overlayfs oci-runtime
Requires:      netavark slirp4netns catatonit conmon >= 2.1.7
Requires:      container-selinux iptables nftables libseccomp >= 2.5
Suggests:      containernetworking-plugins
Recommends:    gvisor-tap-vsock
Provides:      %{name}-manpages = %{version}-%{release}
Provides:      %{name}-quadlet = %{version}-%{release}
Obsoletes:     %{name}-quadlet <= 4.4.0

%description
%{name} (Pod Manager) is a fully featured container engine that is a simple daemonless tool.
%{name} provides a Docker-CLI comparable command line that eases the transition from
other container engines and allows the management of pods, containers and images.
Simply put: alias docker=%{name}.
Most %{name} commands can be run as a regular user, without requiring
additional privileges.

%{name} uses Buildah(1) internally to create container images.
Both tools share image (not container) storage, hence each can use or
manipulate images (but not containers) created by the other.


%package docker
Summary:       Emulate Docker CLI using %{name}
BuildArch:     noarch
Requires:      %{name} = %{version}-%{release}
Conflicts:     docker docker-ce moby

%description docker
This package installs a script named docker that emulates the Docker CLI by
executes %{name} commands, it also creates links between all Docker CLI man
pages and %{name}.


%package remote
Summary: A remote CLI for Podman: A Simple management tool for pods, containers and images

%description remote
%{name}-remote provides a local client interacting with a Podman backend node through
a RESTful API tunneled through a ssh connection. In this context, a %{name} node is
a Linux system with Podman installed on it and the API service activated.

Credentials for this session can be passed in using flags, environment variables,
or in containers.conf.

%package plugins
Summary:       Plugins for %{name}
Requires:      dnsmasq
Recommends:    gvisor-tap-vsock

%description plugins
This plugin sets up the use of dnsmasq on a given CNI network so
that Pods can resolve each other by name.  When configured,
the pod and its IP address are added to a network specific hosts file
that dnsmasq will read in.  Similarly, when a pod
is removed from the network, it will remove the entry from the hosts
file.  Each CNI network will have its own dnsmasq instance.

%package tests
Summary:       Tests for %{name}
Requires:      %{name} = %{version}-%{release}
Requires:      nmap-ncat httpd-tools jq socat
Requires:      skopeo buildah
Requires:      openssl gnupg git-daemon

%description tests
This package contains system tests for %{name}

%package -n %{name}sh
Summary:       Confined login and user shell using %{name}
Requires:      %{name} = %{version}-%{release}
Provides:      %{name}-shell = %{version}-%{release}
Provides:      %{name}-%{name}sh = %{version}-%{release}

%description -n %{name}sh
%{name}sh provides a confined login and user shell with access to volumes and
capabilities specified in user quadlets.

It is a symlink to %{_bindir}/%{name} and execs into the `%{name}sh` container
when `%{_bindir}/%{name}sh` is set as a login shell or set as os.Args[0].

%prep
%autosetup -Sgit -n %{name}-%{version}
sed -i 's;@@PODMAN@@\;$(BINDIR);@@PODMAN@@\;%{_bindir};' Makefile
tar zxf %{SOURCE1}

%build
export CGO_CFLAGS=$CFLAGS
export GO111MODULE=on
export GOPATH=$(pwd)/_build:$(pwd)
CGO_CFLAGS=$(echo $CGO_CFLAGS | sed 's/-flto=auto//g')
CGO_CFLAGS=$(echo $CGO_CFLAGS | sed 's/-Wp,D_GLIBCXX_ASSERTIONS//g')

%ifarch x86_64
export CGO_CFLAGS+=" -m64 -mtune=generic -fcf-protection=full"
%endif

%ifarch loongarch64
go clean -testcache -modcache -cache -fuzzcache
%endif

mkdir _build
pushd _build
mkdir -p src/github.com/containers
ln -s ../../../../ src/github.com/containers/podman
popd
ln -s vendor src

LDFLAGS="-X %{ld_libpod}/define.buildInfo=$(date +%s) \
         -X %{ld_libpod}/config._installPrefix=%{_prefix} \
         -X %{ld_libpod}/config._etcDir=%{_sysconfdir} \
         -X %{ld_project}/pkg/systemd/quadlet._binDir=%{_bindir}"

%gobuild -o bin/rootlessport %{import_path}/cmd/rootlessport

export BASEBUILDTAGS="seccomp exclude_graphdriver_devicemapper $(hack/systemd_tag.sh) $(hack/libsubid_tag.sh)"

export BUILDTAGS="$BASEBUILDTAGS $(hack/btrfs_installed_tag.sh) $(hack/btrfs_tag.sh) $(hack/libdm_tag.sh)"
%gobuild -o bin/%{name} %{import_path}/cmd/%{name}

export BUILDTAGS="$BASEBUILDTAGS exclude_graphdriver_btrfs btrfs_noversion remote"
%gobuild -o bin/%{name}-remote %{import_path}/cmd/%{name}

%gobuild -o bin/quadlet %{import_path}/cmd/quadlet

LDFLAGS=''
%{__make} docs docker-docs

pushd %{repo_plugins}-%{commit_plugins}
mkdir _build
pushd _build
mkdir -p src/%{container_base_path}
ln -s ../../../../ src/%{import_path_plugins}
popd
ln -s vendor src
export GOPATH=$(pwd)/_build:$(pwd)
%gobuild -o bin/dnsname %{import_path_plugins}/plugins/meta/dnsname
popd

%install
install -dp %{buildroot}%{_unitdir}
PODMAN_VERSION=%{version} %{__make} PREFIX=%{buildroot}%{_prefix} ETCDIR=%{buildroot}%{_sysconfdir} \
        install.bin \
        install.remote \
        install.man \
        install.systemd \
        install.completions \
        install.docker \
        install.docker-docs \
        install.remote

sed -i 's;%{buildroot};;g' %{buildroot}%{_bindir}/docker
cd %{repo_plugins}-%{commit_plugins}
%{__make} PREFIX=%{_prefix} DESTDIR=%{buildroot} install
cd ..

for file in `find %{buildroot}%{_mandir}/man[15] -type f | sed "s,%{buildroot},," | grep -v -e remote -e docker`; do
    echo "$file*" >> podman.file-list
done
rm -f %{buildroot}%{_mandir}/man5/docker*.5

install -d -p %{buildroot}/%{_datadir}/%{name}/test/system
cp -pav test/system %{buildroot}/%{_datadir}/%{name}/test/

%check
%if 0%{?with_check}
ln -s ./ ./vendor/src

export GOPATH=%{buildroot}/%{gopath}:$(pwd)/vendor:%{gopath}

%if ! 0%{?gotest:1}
%global gotest go test
%endif

%gotest %{import_path}/cmd/%{name}
%gotest %{import_path}/libkpod
%gotest %{import_path}/libpod
%gotest %{import_path}/pkg/registrar
%endif

%files -f podman.file-list
%license LICENSE
%doc README.md CONTRIBUTING.md install.md transfer.md
%{_bindir}/%{name}
%dir %{_libexecdir}/%{name}
%{_libexecdir}/%{name}/quadlet
%{_libexecdir}/%{name}/rootlessport
%{_unitdir}/*.service
%{_unitdir}/*.socket
%{_unitdir}/*.timer
%{_userunitdir}/*.service
%{_userunitdir}/*.socket
%{_userunitdir}/*.timer
%{_usr}/lib/tmpfiles.d/%{name}.conf
%{_usr}/lib/systemd/system-generators/podman-system-generator
%{_usr}/lib/systemd/user-generators/podman-user-generator
%{_datadir}/bash-completion/completions/%{name}
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_%{name}
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/%{name}.fish


%files docker
%{_bindir}/docker
%{_usr}/lib/tmpfiles.d/%{name}-docker.conf
%{_datadir}/user-tmpfiles.d/podman-docker.conf
%{_mandir}/man1/docker*.1*


%files remote
%license LICENSE
%{_bindir}/%{name}-remote
%{_mandir}/man1/%{name}-remote*.*
%{_datadir}/bash-completion/completions/%{name}-remote
%dir %{_datadir}/fish
%dir %{_datadir}/fish/vendor_completions.d
%{_datadir}/fish/vendor_completions.d/%{name}-remote.fish
%dir %{_datadir}/zsh
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_%{name}-remote

%files plugins
%license %{repo_plugins}-%{commit_plugins}/LICENSE
%doc %{repo_plugins}-%{commit_plugins}/{README.md,README_PODMAN.md}
%dir %{_libexecdir}/cni
%{_libexecdir}/cni/dnsname

%files tests
%license LICENSE
%{_datadir}/%{name}/test

%files -n %{name}sh
%{_bindir}/%{name}sh

%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.9.5-4
- Rebuilt for loongarch release

* Mon Jul 29 2024 Pengda Dou <doupengda@loongson.cn> - 4.9.5-3
- [Type] other
- [DESC] fix build error for loongarch64

* Mon Jul 15 2024 Pengda Dou <doupengda@loongson> - 4.9.5-2
- [Type] other
- [DESC] fix build error for loongarch64

* Wed Jun 05 2024 jackeyji <jackeyji@tencent.com> - 4.9.5-1
- [Type] other
- [DESC] upgrade to 4.9.5 to fix CVE-2024-1753 CVE-2024-3727 CVE-2024-24786 and CVE-2024-28180

* Wed May 8 2024 Pengda Dou <doupengda@loongson.cn> - 4.9.3-2
- [Type] other
- [DESC] add support for loongarch64

* Fri Mar 08 2024 jackeyji <jackeyji@tencent.com> - 4.9.3-1
- Upgrade to 4.9.3 to adapt moby

* Fri Dec 29 2023 jackeyji <jackeyji@tencent.com> - 4.5.1-4
- Rebuilt for golang CVE-2023-39318 and CVE-2023-39319

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.5.1-3
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Aug 04 2023 Xiaojie Chen <jackxjchen@tencent.com> - 4.5.1-2
- Rebuilt for file 5.45

* Wed Jul 12 2023 kianli <kianli@tencent.com> - 4.5.1-1
- Upgrade to 4.5.1

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 4.4.4-4
- Rebuilt for OpenCloudOS Stream 23.05

* Mon Apr 17 2023 rockerzhu <rockerzhu@tencent.com> - 4.4.4-3
- Delete annobin treatment in flags.

* Fri Apr 07 2023 rockerzhu <rockerzhu@tencent.com> - 4.4.4-2
- Don't provides docker, being provided by moby.

* Fri Apr 07 2023 rockerzhu <rockerzhu@tencent.com> - 4.4.4-1
- Initial build.
